#include <windows.h>

#include "GUI.h"

/*********************************************************************
*
*       _cbGetData
*
* Purpose:
*   Callback function for getting font data
*
* Parameters:
*   Off      - Position of XBF file to be read
*   NumBytes - Number of requested bytes
*   pVoid    - Application defined pointer
*   pBuffer  - Pointer to buffer to be filled by the function
*
* Return value:
*   0 on success, 1 on error
*/
static int _cbGetDataXBF(U32 Off, U16 NumBytes, void * pVoid, void * pBuffer) {
  DWORD NumBytesRead;
  HANDLE hFile;

  hFile = *(HANDLE *)pVoid;
  //
  // Set file pointer to the requested position
  //
  if (SetFilePointer(hFile, Off, 0, FILE_BEGIN) == 0xFFFFFFFF) {
    return 1; // Error
  }
  //
  // Read font data
  //
  if (!ReadFile(hFile, pBuffer, NumBytes, &NumBytesRead, 0)) {
    return 1; // Error
  }
  if (NumBytesRead != NumBytes) {
    return 1; // Error
  }
  return 0; // Ok
}

/*********************************************************************
*
*       MainTask
*/
void MainTask(void) {
  HANDLE       hFile;
  GUI_FONT     Font;
  GUI_XBF_DATA XBF_Data;

  GUI_Init();
  //
  // Get file handle
  //
  hFile = CreateFile("C:\\Work\\emWin_Training\\Samples\\FontConverter\\FontASCII_16_XBF.xbf", GENERIC_READ, 0, 0, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, 0);
  //
  // Create XBF font
  //
  GUI_XBF_CreateFont(&Font,                 // Pointer to GUI_FONT structure in RAM
                     &XBF_Data,             // Pointer to GUI_XBF_DATA structure in RAM
                     GUI_XBF_TYPE_PROP_EXT, // Font type to be created
                     _cbGetDataXBF,         // Pointer to callback function
                     (void *)&hFile);       // Pointer to be passed to GetData function
  //
  // Draw some text
  //
  GUI_DispStringHCenterAt("Hello world!", 160, 80);
  while (1) {
    GUI_Delay(100);
  }
}
